[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)

# Terrestrial Radar Assessment of Calving Wave Activity (TeRACWA)

TeRACWA is a novel automated method for the detection and the analysis of ocean waves generated by glacier calving from Terrestrial Radar Interferometer (TRI) acquisitions of backscatter intensity. For a complete description of the method and the results of a case study on Eqip Sermia, Greenland, see [Wehrlé et al, 2021](https://tc.copernicus.org/preprints/tc-2021-33/).

## Environment setup

It is recommended to use TeRACWA in a [conda](https://docs.conda.io/projects/conda/en/latest/user-guide/tasks/manage-environments.html) environment that can be created with the ```TeRACWA_environment.yml``` environment file as follows.
``` bash
conda env create -f TeRACWA_environment.yml
```
To complete the environment setup, [gpritools](https://git.sr.ht/~scinu/gpritools) needs to be cloned and made available for import by e.g. updating ```PYTHONPATH```. It can also be modified using standard list operations as follows.

``` python
import sys
sys.path.append('/path/to/gpritools')
``` 

## Module usage

The easiest and most direct way to run TeRACWA is to import it as a module and run the wrapper method with the default arguments.

``` python
import TeRACWA

# create an instance of TeRACWA with default run parameters
my_teracwa = TeRACWA(slc_directory='/path/to/slc')

# run TeRAWA wrapper
my_teracwa.run()
``` 

In this case, the different steps of TeRACWA are run with the parameters described in [Wehrlé et al, 2021](https://tc.copernicus.org/preprints/tc-2021-33/). The results were saved locally in the class attribute ```my_teracwa.results``` which is a dictionnary containing the outputs of the different steps, and the whole instance (including run parameters) was saved in a pickle file in the current directory.

The different steps can also be be run individually and some intermediate results affected to a local variable. See example below where the raw TeRACWA results are stored in the ```raw_power_maxima``` variable as a two-dimensional ```numpy.ndarray```.

``` python
import TeRACWA

# create a TeRACWA instance
my_teracwa = TeRACWA(slc_directory='/path/to/slc')

# list the files to process
my_teracwa.list_slc_files()

# get general acquisition characteristics
my_teracwa.get_data_specs()

# run the core method of TeRACWA
raw_power_maxima = my_teracwa.run_spectral_analysis()
``` 

## Reference

Wehrlé, A., Lüthi, M.P., Walter, A., Jouvet, G. and Vieli, A., 2021. Automated detection and analysis of surface calving waves with a terrestrial radar interferometer at the front of Eqip Sermia, Greenland. The Cryosphere Discussions, pp.1-24.
